@@ -1,4 +1,6 @@
-from typing import Any, Optional
+from __future__ import annotations
+
+from typing import Any
 
 from vial import timestamps
 from vial.errors import ServerError
@@ -6,7 +8,7 @@ from vial.types import Request
 
 
 class RequestContext:
-    _INSTANCE: Optional["RequestContext"] = None
+    _INSTANCE: RequestContext | None = None
 
     def __init__(self, request: Request) -> None:
         self.request = request
@@ -20,7 +22,7 @@ class RequestContext:
     def remaining_time(self) -> int:
         return self.request.context.get_remaining_time_in_millis()
 
-    def __enter__(self) -> "RequestContext":
+    def __enter__(self) -> RequestContext:
         RequestContext._INSTANCE = self
         return self
 
@@ -28,7 +30,7 @@ class RequestContext:
         RequestContext._INSTANCE = None
 
     @classmethod
-    def active(cls) -> "RequestContext":
+    def active(cls) -> RequestContext:
         if not cls._INSTANCE:
             raise ServerError("Not currently within a request")
         return cls._INSTANCE
